@@ -79,7 +79,7 @@ my $XX       = $screen_width;
 my $YY       = $screen_height;
 my $center_x = $F->{'X_CLIP'} + ($F->{'W_CLIP'} / 2);
 my $center_y = $F->{'Y_CLIP'} + ($F->{'H_CLIP'} / 2);
-my $factor   = 3;
+my $factor   = 5;
 my $rpi      = ($FR->{'fscreeninfo'}->{'id'} =~ /BCM270(8|9)/i) ? 1 : 0;
 
 $factor *= 3 if ($rpi);    # Raspberry PI is sloooooow.  Let's give extra time for each test
@@ -141,7 +141,7 @@ $F->cls('OFF');
 $DIRTY = 1;    # Set this to signal the buffer needs flipping
 sleep 4;
 
- if (0) { # This line only used for debugging
+# if (0) { # This line only used for debugging
 color_mapping();
 plotting();
 foreach my $flag (0 .. 1) {
@@ -198,7 +198,7 @@ color_replace_no_clipping();
 
 blitting();
 blit_move();
-rotate();}
+rotate();
 flipping();
 monochrome();
 foreach my $m (1 .. 9) {    # We skip divide mode because it's stupid and I should never have added it
@@ -1320,7 +1320,7 @@ sub rotate {
             $DIRTY = 1;
 
             $angle -= 3;
-            $angle = 0 if ($angle <= -360);
+            $angle  = 0 if ($angle <= -360);
             $count++;
 
         } ## end while (time < $s || $count...)
